@@ -86,7 +86,7 @@
 #define SONNETUI_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef SONNETUI_NO_DEPRECATED
-#  define SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54800
+#  define SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
 #endif
 #ifdef SONNETUI_NO_DEPRECATED_WARNINGS
 #  define SONNETUI_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define SONNETUI_DEPRECATED_WARNINGS_SINCE SONNETUI_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define SONNETUI_DEPRECATED_WARNINGS_SINCE 0x54800
+#    define SONNETUI_DEPRECATED_WARNINGS_SINCE 0x54a00
 #  endif
 #endif
 
